{ inputs, pkgs, config, ... }:
{
    imports = [ inputs.ags.homeManagerModules.default ];
    home.packages = [
        pkgs.adw-gtk3
        pkgs.papirus-icon-theme
    ];
    programs.ags = {
        enable = true;
        extraPackages = with pkgs; [
            gtksourceview
            webkitgtk
            accountsservice
        ];
    };
    home.file."${config.xdg.configHome}/ags" = {
        source = ./files;
        recursive = true;
    };
    home.file."${config.xdg.configHome}/ags/settings.json".text = pkgs.lib.mkDefault (builtins.toJSON {
        temperature-cmd = "bash -c 'sensors | grep Package | cut -c17-23'";
    });
    home.file."${config.xdg.configHome}/ags/style.css".text = ''
      window.bar {
          background-color: rgba(0, 0, 0, 0.2);
          font-size: 1em;
          font-family: "Noto Sans", "FontAwesome";
      }

      .systray-item {
          margin-left: 0.4em;
          margin-right: 0.4em;
      }

      .systray {
          margin-left: 0.6em;
      }

      .window-box {
          margin-bottom: 0.3em;
          margin-top: 0.2em;
      }

      .clients box {
          margin-right: 0.3em;
      }

      .item, .clients box {
          background: #1f2430;
          padding-left: 0.7em;
          padding-right: 0.7em;
          border-radius: 0.3em;
      }

      .app-icon {
          margin-right: 0.6em;
      }

      button {
          background: #1f2430;
          border:none;
          padding: 0.2em;
          border-radius: 0.3em;
      }

      .focused, .clients box.focused {
          background: #023269;
      }

      button:hover {
          background: #023269;
      }

      .workspaces button {
          padding-left: 0.4em;
          padding-right: 0.4em;
          margin-left: 0.2em;
          margin-right: 0.2em;
      }

      .notification {
          color: yellow;
      }

      .blue {
          background: #023269;
      }

      /* Notifications */
      window.notification-popups box.notifications {
          padding: .5em;
      }

      .icon {
          min-width: 68px;
          min-height: 68px;
          margin-right: 1em;
      }

      .icon image {
          font-size: 58px;
          /* to center the icon */
          margin: 5px;
          color: @theme_fg_color;
      }

      .icon box {
          min-width: 68px;
          min-height: 68px;
          border-radius: 7px;
      }

      .notification {
          min-width: 350px;
          border-radius: 11px;
          padding: 1em;
          margin: .5em;
          background-color: #1f2430;
      }

      .notification.critical {
          border: 1px solid lightcoral;
      }

      .title {
          color: @theme_fg_color;
          font-size: 1.4em;
      }

      .body {
          color: @theme_unfocused_fg_color;
      }

      .actions .action-button {
          margin: 0 .4em;
          margin-top: .8em;
      }

      .actions .action-button:first-child {
          margin-left: 0;
      }

      .actions .action-button:last-child {
          margin-right: 0;
      }
    '';
}
